@@ -29,11 +29,9 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 /* SCO 3.2v4 curses.h includes term.h, which defines lines as a macro.
    Undefine it here, because CursesWindow uses lines as a method.  */
-#ifdef lines
 #undef lines
-#endif
 
-// "Convert" Macros To Inlines, if needed.
+// "Convert" macros to inlines, if needed.
 #ifdef addch
 inline int (addch)(char ch)  { return addch(ch); }
 #undef addch
@@ -135,11 +133,33 @@ inline int (standend)()  { return standend(); }
 inline int (standout)()  { return standout(); }
 #undef standout
 #endif
+#ifdef wstandend
+inline int (wstandend)(WINDOW *win)  { return wstandend(win); }
+#undef wstandend
+#endif
+#ifdef wstandout
+inline int (wstandout)(WINDOW *win)  { return wstandout(win); }
+#undef wstandout
+#endif
 #ifdef winch
 inline int (winch)(WINDOW* win) { return winch(win); }
 #undef winch
 #endif
 
+/* deal with conflicting macros in ncurses.h  which is SYSV based*/
+#ifdef box
+inline (box)(WINDOW* win, chtype v, chtype h) {return box(win, v, h); }
+#undef box
+#endif
+#ifdef scroll
+inline (scroll)(WINDOW* win) { return scroll(win); }
+#undef scroll
+#endif
+#ifdef touchwin
+inline (touchwin)(WINDOW* win) { return touchwin(win); }
+#undef touchwin
+#endif
+
 #ifdef mvwaddch
 inline int (mvwaddch)(WINDOW *win, int y, int x, char ch)
 { return mvwaddch(win, y, x, ch); }
